==> quick-react-notification-1.0.2.tgz: package/es/components/Notification.js <==
/* eslint-disable no-func-assign */
import React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faCheckCircle, faInfoCircle, faExclamationCircle, faExclamationTriangle, faTimes } from '@fortawesome/free-solid-svg-icons';
import { useNotification } from '../context/notification-context';

function getNotificationData(type) {
  switch (type) {
    case 'error':
      return {
        backgroundColor: '#f8615a',
        src: faExclamationTriangle
      };

    case 'warning':
      return {
        backgroundColor: '#ffd369',
        src: faExclamationCircle
      };

    case 'info':
      return {
        backgroundColor: '#f4f9f4',
        src: faInfoCircle
      };

    default:
      return {
        backgroundColor: '#adce74',
        src: faCheckCircle
      };
  }
}

function Notification(_ref) {
  var type = _ref.type,
      message = _ref.message,
      isOpen = _ref.isOpen,
      id = _ref.id;

  var _useNotification = useNotification(),
      removeNotification = _useNotification.removeNotification;

  var _getNotificationData = getNotificationData(type),
      backgroundColor = _getNotificationData.backgroundColor,
      src = _getNotificationData.src;

  return isOpen && /*#__PURE__*/React.createElement("div", {
    style: {
      backgroundColor: backgroundColor,
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      width: 'fit-content',
      borderRadius: '3px',
      padding: '10px 15px',
      margin: '5px 0'
    }
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: src
  }), /*#__PURE__*/React.createElement("p", {
    style: {
      margin: '0 10px',
      fontSize: '14px'
    }
  }, message), /*#__PURE__*/React.createElement("button", {
    style: {
      background: 'none',
      border: 'none',
      display: 'flex',
      padding: 0
    },
    onClick: function onClick() {
      return removeNotification(id);
    }
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: faTimes
  })));
}

Notification = React.memo(Notification);
export default Notification;

==> quick-react-notification-1.0.8.tgz: package/es/components/Notification.js <==
/* eslint-disable no-func-assign */
import React from 'react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faCheckCircle, faInfoCircle, faExclamationCircle, faExclamationTriangle, faTimes } from '@fortawesome/free-solid-svg-icons';
import { useNotification } from '../context/notification-context';

function getNotificationData(type, extendTypes) {
  if (extendTypes) {
    var data = extendTypes(type);
    if (data) return data;
  }

  switch (type) {
    case 'error':
      return {
        backgroundColor: '#f8615a',
        src: faExclamationTriangle
      };

    case 'warning':
      return {
        backgroundColor: '#ffd369',
        src: faExclamationCircle
      };

    case 'info':
      return {
        backgroundColor: '#f4f9f4',
        src: faInfoCircle
      };

    default:
      return {
        backgroundColor: '#adce74',
        src: faCheckCircle
      };
  }
}

function Notification(_ref) {
  var type = _ref.type,
      message = _ref.message,
      isOpen = _ref.isOpen,
      id = _ref.id,
      extendTypes = _ref.extendTypes;

  var _useNotification = useNotification(),
      removeNotification = _useNotification.removeNotification;

  var _getNotificationData = getNotificationData(type, extendTypes),
      backgroundColor = _getNotificationData.backgroundColor,
      src = _getNotificationData.src;

  return isOpen && /*#__PURE__*/React.createElement("div", {
    style: {
      backgroundColor: backgroundColor,
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      width: 'fit-content',
      borderRadius: '3px',
      padding: '10px 15px',
      margin: '5px 0'
    }
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: src
  }), /*#__PURE__*/React.createElement("p", {
    style: {
      margin: '0 10px',
      fontSize: '14px'
    }
  }, message), /*#__PURE__*/React.createElement("button", {
    style: {
      background: 'none',
      border: 'none',
      display: 'flex',
      padding: 0,
      cursor: 'pointer'
    },
    onClick: function onClick() {
      return removeNotification(id);
    }
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    icon: faTimes
  })));
}

Notification = React.memo(Notification);
export default Notification;
